import { pushTagToGTM } from '../util/gtm/cos-gtm';
import {
  campaignBookADemo,
  campaignBookADemoFooter,
  campaignHeroClick,
  campaignToolbarClick
} from '../util/gtm/tags-collection';
import { PUBLIC_URLS } from "../config/public-endpoints";

/**
 * returns the entered user input
 * @returns {string} user mail address
 */
const getUserMail = (inputClass) => {
  const data = $(`.demo-input.${inputClass}`).filter(function () {
    return !!this.value;
  });

  return data[0].value;
};

/**
 * posts user input to the backend
 * TODO: verify email with regex!
 */
const postUserMailToBookADemo = (mail) => {
  $.ajax({
    type: 'POST',
    url: PUBLIC_URLS.sellerBookADemo,
    data: JSON.stringify({ mail }),
    contentType: 'application/json',
    success: function () {
      $('.success').css({'display': 'block'});
      $('.error').css({'display': 'none'});
    },
    error: function (error) {
      $('.error').css({'display': 'block'});
      $('.success').css({'display': 'none'});
    }
  })
};

/**
 * scrolls to the book a demo sections
 */
const scrollToBookADemo = () => {
  $('html,body').animate({
    scrollTop: $('#getstarted').offset().top
  }, 600);
};

/**
 * inits onClick listener for the toolbar campaign button
 */
const initToolbarButtonClickListener = () => {
  $('.primary-button.campaign.toolbar').on('click', function () {
    pushTagToGTM(campaignToolbarClick);

    scrollToBookADemo();
  });
};

/**
 * inits onClick listener for the hero campaign button
 */
const initHeroButtonClickListener = () => {
  $('.primary-button.campaign.hero').on('click', function () {
    pushTagToGTM(campaignHeroClick);

    scrollToBookADemo();
  })
};

/**
 * inits onClick listener for the book a demo button (middle section)
 */
const initBookADemoClickListener = () => {
  $('.form.campaign.middle-section').submit(function (e) {
    e.preventDefault();
    pushTagToGTM(campaignBookADemo);

    const mail = getUserMail('middle-section');

    postUserMailToBookADemo(mail);
  });
};

/**
 * inits onClick listener for the footer book a demo submit button
 */
const initFooterBookADemoClickListener = () => {
  $('.form.campaign.footer-form').submit(function (e) {
    e.preventDefault();
    pushTagToGTM(campaignBookADemoFooter);

    const mail = getUserMail('footer-section');

    postUserMailToBookADemo(mail);
  });
};

/**
 * campaign click events
 * @type {{init: campaignEvents.init}}
 */
export const campaignEvents = (() => ({
  init: function () {
    initToolbarButtonClickListener();
    initHeroButtonClickListener();

    // getting webflow javascript
    const webflow = Webflow || [];

    webflow.push(function () {
      $(document).off('submit');

      initBookADemoClickListener();
      initFooterBookADemoClickListener();
    });
  },
}))();
